@@ -2,9 +2,9 @@
     it87.c - Part of lm_sensors, Linux kernel modules for hardware
              monitoring.
 
-    Supports: IT8705F  Super I/O chip w/LPC interface & SMBus
+    Supports: IT8705F  Super I/O chip w/LPC interface
               IT8712F  Super I/O chip w/LPC interface & SMBus
-              Sis950   A clone of the IT8705F
+              SiS950   A clone of the IT8705F
 
     Copyright (c) 2001 Chris Gauthron <chrisg@0-in.com> 
     Largely inspired by lm78.c of the same package
@@ -215,8 +215,7 @@ extern inline u8 DIV_TO_REG(long val)
 }
 #define DIV_FROM_REG(val) (1 << (val))
 
-/* For each registered IT87, we need to keep some data in memory. That
-   data is pointed to by it87_list[NR]->data. The structure itself is
+/* For each registered IT87, we need to keep some data in memory. It is
    dynamically allocated, at the same time when a new it87 client is
    allocated. */
 struct it87_data {
@@ -250,7 +249,6 @@ struct it87_data {
 
 
 static int it87_attach_adapter(struct i2c_adapter *adapter);
-static int it87_find(int *address);
 static int it87_detect(struct i2c_adapter *adapter, int address,
 		       unsigned short flags, int kind);
 static int it87_detach_client(struct i2c_client *client);
@@ -308,9 +306,9 @@ static struct i2c_driver it87_driver = {
 #define IT87_SYSCTL_FAN1 1101   /* Rotations/min */
 #define IT87_SYSCTL_FAN2 1102
 #define IT87_SYSCTL_FAN3 1103
-#define IT87_SYSCTL_TEMP1 1200  /* Degrees Celcius * 10 */
-#define IT87_SYSCTL_TEMP2 1201  /* Degrees Celcius * 10 */
-#define IT87_SYSCTL_TEMP3 1202  /* Degrees Celcius * 10 */
+#define IT87_SYSCTL_TEMP1 1200  /* Degrees Celsius * 10 */
+#define IT87_SYSCTL_TEMP2 1201  /* Degrees Celsius * 10 */
+#define IT87_SYSCTL_TEMP3 1202  /* Degrees Celsius * 10 */
 #define IT87_SYSCTL_VID 1300    /* Volts * 100 */
 #define IT87_SYSCTL_FAN_DIV 2000        /* 1, 2, 4 or 8 */
 #define IT87_SYSCTL_ALARMS 2004    /* bitvector */
@@ -335,6 +333,8 @@ static struct i2c_driver it87_driver = {
 #define IT87_ALARM_FAN1 0x0001
 #define IT87_ALARM_FAN2 0x0002
 #define IT87_ALARM_FAN3 0x0004
+#define IT87_ALARM_FAN4 0x0008
+#define IT87_ALARM_FAN5 0x0040
 #define IT87_ALARM_TEMP1 0x00010000
 #define IT87_ALARM_TEMP2 0x00020000
 #define IT87_ALARM_TEMP3 0x00040000
@@ -424,7 +424,7 @@ static int it87_attach_adapter(struct i2c_adapter *adapter)
 	return i2c_detect(adapter, &addr_data, it87_detect);
 }
 
-static int it87_find(int *address)
+static int __init it87_find(int *address)
 {
 	int err = -ENODEV;
 	u16 devid;
@@ -435,7 +435,7 @@ static int it87_find(int *address)
 		goto exit;
 
 	superio_select();
-	if (!(superio_inb(IT87_ACT_REG)) & 0x01) {
+	if (!(superio_inb(IT87_ACT_REG) & 0x01)) {
 		printk(KERN_INFO "it87: Device not activated, skipping\n");
 		goto exit;
 	}
@@ -456,8 +456,8 @@ exit:
 }
 
 /* This function is called by i2c_detect */
-int it87_detect(struct i2c_adapter *adapter, int address,
-		unsigned short flags, int kind)
+static int it87_detect(struct i2c_adapter *adapter, int address,
+		       unsigned short flags, int kind)
 {
 	int i;
 	struct i2c_client *new_client;
@@ -622,7 +622,7 @@ static int it87_detach_client(struct i2c_client *client)
 	return 0;
 }
 
-/* The SMBus locks itself, but ISA access must be locked explicitely! 
+/* The SMBus locks itself, but ISA access must be locked explicitly! 
    We don't want to lock the whole ISA bus, so we lock each client
    separately.
    We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
@@ -642,7 +642,7 @@ static int it87_read_value(struct i2c_client *client, u8 reg)
 		return i2c_smbus_read_byte_data(client, reg);
 }
 
-/* The SMBus locks itself, but ISA access muse be locked explicitely! 
+/* The SMBus locks itself, but ISA access muse be locked explicitly! 
    We don't want to lock the whole ISA bus, so we lock each client
    separately.
    We ignore the IT87 BUSY flag at this moment - it could lead to deadlocks,
@@ -1020,7 +1020,7 @@ void it87_fan_div(struct i2c_client *client, int operation, int ctl_name,
 		old = it87_read_value(client, IT87_REG_FAN_DIV);
 		if (*nrels_mag >= 3) {
 			data->fan_div[2] = DIV_TO_REG(results[2]);
-			if( data->fan[2]!=3 ) {
+			if (data->fan_div[2] != 3) {
 				data->fan_div[2] = 1;
 				old = (old & 0xbf);
 			} else {
@@ -1121,7 +1121,6 @@ static void __exit sm_it87_exit(void)
 }
 
 
-
 MODULE_AUTHOR("Chris Gauthron <chrisg@0-in.com>");
 MODULE_DESCRIPTION("IT8705F, IT8712F, Sis950 driver");
 MODULE_PARM(update_vbat, "i");
