@@ -276,9 +276,7 @@ static int lm93_id = 0;
 
 struct lm93_data {
 	struct i2c_client client;
-	struct semaphore lock;
 	int sysctl_id;
-	enum chips type;
 
 	struct semaphore update_lock;
 	unsigned long last_updated;	/* In jiffies */
@@ -1111,7 +1109,7 @@ static void lm93_prochot(struct i2c_client *client, int operation,
 	else if (operation == SENSORS_PROC_REAL_READ) {
 		lm93_update_client(client);
 		results[0] = data->prochot_max[nr];
-		results[1] = data->block4[nr].avg;
+		results[1] = data->block4[nr].cur;
 		results[2] = data->block4[nr].avg;
 		*nrels_mag = 3;
 	} else if (operation == SENSORS_PROC_REAL_WRITE) {
@@ -2227,7 +2225,6 @@ static int lm93_detect(struct i2c_adapter *adapter, int address,
 
 	client = &data->client;
 	client->addr = address;
-	init_MUTEX(&data->lock);
 	client->data = data;
 	client->adapter = adapter;
 	client->driver = &lm93_driver;
@@ -2266,7 +2263,6 @@ static int lm93_detect(struct i2c_adapter *adapter, int address,
 		client->name, i2c_adapter_id(client->adapter), client->addr);
 
 	/* housekeeping */
-	data->type = kind;
 	data->valid = 0;
 	data->update = update;
 	init_MUTEX(&data->update_lock);
