@@ -161,8 +161,7 @@ static inline u8 FAN_TO_REG(long rpm, int div)
 #define DIV_FROM_REG(val) (1 << (val))
 #define DIV_TO_REG(val) ((val)==8?3:(val)==4?2:(val)==1?0:1)
 
-/* For the SIS5595, we need to keep some data in memory. That
-   data is pointed to by sis5595_list[NR]->data. The structure itself is
+/* For the SIS5595, we need to keep some data in memory. It is
    dynamically allocated, at the time when the new sis5595 client is
    allocated. */
 struct sis5595_data {
@@ -200,7 +199,6 @@ static int sis5595_write_value(struct i2c_client *client, u8 register,
 			       u8 value);
 static void sis5595_update_client(struct i2c_client *client);
 static void sis5595_init_client(struct i2c_client *client);
-static int sis5595_find_sis(int *address);
 
 
 static void sis5595_in(struct i2c_client *client, int operation,
@@ -234,7 +232,7 @@ static struct i2c_driver sis5595_driver = {
 #define SIS5595_SYSCTL_IN4 1004
 #define SIS5595_SYSCTL_FAN1 1101	/* Rotations/min */
 #define SIS5595_SYSCTL_FAN2 1102
-#define SIS5595_SYSCTL_TEMP 1200	/* Degrees Celcius * 10 */
+#define SIS5595_SYSCTL_TEMP 1200	/* Degrees Celsius * 10 */
 #define SIS5595_SYSCTL_FAN_DIV 2000	/* 1, 2, 4 or 8 */
 #define SIS5595_SYSCTL_ALARMS 2001	/* bitvector */
 
@@ -286,7 +284,7 @@ static int sis5595_attach_adapter(struct i2c_adapter *adapter)
 }
 
 /* Locate SiS bridge and correct base address for SIS5595 */
-static int sis5595_find_sis(int *address)
+static int __init sis5595_find_sis(int *address)
 {
 	u16 val;
 	int *i;
