@@ -184,6 +184,30 @@
 #define SENSORS_ADM1021_ALARMS 81 /* R */
 #define SENSORS_ADM1021_DIE_CODE 90 /* R */
 
+/* ADM1029 chips */
+
+#define SENSORS_ADM1029_PREFIX "adm1029"
+
+#define SENSORS_ADM1029_TEMP1		51
+#define SENSORS_ADM1029_TEMP1_MAX	52
+#define SENSORS_ADM1029_TEMP1_MIN	53
+
+#define SENSORS_ADM1029_TEMP2		61
+#define SENSORS_ADM1029_TEMP2_MAX	62
+#define SENSORS_ADM1029_TEMP2_MIN	63
+
+#define SENSORS_ADM1029_TEMP3		71
+#define SENSORS_ADM1029_TEMP3_MAX	72
+#define SENSORS_ADM1029_TEMP3_MIN	73
+
+#define SENSORS_ADM1029_FAN1		81
+#define SENSORS_ADM1029_FAN1_MIN	82
+#define SENSORS_ADM1029_FAN1_DIV	83
+
+#define SENSORS_ADM1029_FAN2		91
+#define SENSORS_ADM1029_FAN2_MIN	92
+#define SENSORS_ADM1029_FAN2_DIV	93
+
 
 /* ADM1030 and ADM1031 chips */
 
@@ -476,7 +500,7 @@
 #define SENSORS_LM85_ZONE3_RANGE           100  /* RW -- zone3_range  */
 #define SENSORS_LM85_ZONE3_SMOOTH          101  /* RW -- zone3_smooth  */
 
-/* LM86/LM89/LM90/LM99/ADM1032/MAX6657/ADT7461 chips */
+/* LM86/LM89/LM90/LM99/ADM1032/MAX6657/MAX6680/ADT7461 chips */
 
 #define SENSORS_LM90_PREFIX "lm90"
 #define SENSORS_ADM1032_PREFIX "adm1032"
@@ -484,6 +508,7 @@
 #define SENSORS_LM86_PREFIX "lm86"
 #define SENSORS_MAX6657_PREFIX "max6657"
 #define SENSORS_ADT7461_PREFIX "adt7461"
+#define SENSORS_MAX6680_PREFIX "max6680"
 
 #define SENSORS_LM90_LOCAL_TEMP 51 /* R */
 #define SENSORS_LM90_LOCAL_HIGH 52 /* RW */
@@ -868,9 +893,11 @@
 #define SENSORS_W83L785TS_TEMP_OVER	52 /* R for now */
 
 
-/* Winbond W83627EHF Super-I/O chips */
+/* Winbond W83627EHF & W83627DHG Super-I/O chips */
+/* (W83627DHG is similar to W83627EHF but no in9) */
 
 #define SENSORS_W83627EHF_PREFIX	"w83627ehf"
+#define SENSORS_W83627DHG_PREFIX	"w83627dhg"
 
 #define SENSORS_W83627EHF_IN0		1 /* R */
 #define SENSORS_W83627EHF_IN1		2 /* R */
@@ -944,6 +971,12 @@
 #define SENSORS_W83627EHF_TEMP1_HYST	81 /* RW */
 #define SENSORS_W83627EHF_TEMP2_HYST	82 /* RW */
 #define SENSORS_W83627EHF_TEMP3_HYST	83 /* RW */
+#define SENSORS_W83627EHF_TEMP1_TYPE	91 /* R  */
+#define SENSORS_W83627EHF_TEMP2_TYPE	92 /* R  */
+#define SENSORS_W83627EHF_TEMP3_TYPE	93 /* R  */
+#define SENSORS_W83627EHF_VID		245 /* R  */
+#define SENSORS_W83627EHF_VRM		249 /* R  */
+#define SENSORS_W83627EHF_ALARMS	250 /* R  */
 
 
 /* Analog Devices ADM9240 chips */
@@ -1595,9 +1628,13 @@
 #define SENSORS_IT87_FAN1 31 /* R */
 #define SENSORS_IT87_FAN2 32 /* R */
 #define SENSORS_IT87_FAN3 33 /* R */
+#define SENSORS_IT87_FAN4 34 /* R */
+#define SENSORS_IT87_FAN5 35 /* R */
 #define SENSORS_IT87_FAN1_MIN 41 /* RW */
 #define SENSORS_IT87_FAN2_MIN 42 /* RW */
 #define SENSORS_IT87_FAN3_MIN 43 /* RW */
+#define SENSORS_IT87_FAN4_MIN 44 /* RW */
+#define SENSORS_IT87_FAN5_MIN 45 /* RW */
 #define SENSORS_IT87_TEMP1 51 /* R */
 #define SENSORS_IT87_TEMP2 52 /* R */
 #define SENSORS_IT87_TEMP3 53 /* R */
@@ -1808,13 +1845,17 @@
 #define SENSORS_VT1211_UCH 84 /* RW */
 
 #define SENSORS_SMSC47M1_PREFIX "smsc47m1"
+#define SENSORS_SMSC47M2_PREFIX "smsc47m2"
 
 #define SENSORS_SMSC47M1_FAN1 31 /* R */
 #define SENSORS_SMSC47M1_FAN2 32 /* R */
+#define SENSORS_SMSC47M1_FAN3 33 /* R */
 #define SENSORS_SMSC47M1_FAN1_MIN 41 /* RW */
 #define SENSORS_SMSC47M1_FAN2_MIN 42 /* RW */
+#define SENSORS_SMSC47M1_FAN3_MIN 43 /* RW */
 #define SENSORS_SMSC47M1_FAN1_DIV 75 /* RW */
 #define SENSORS_SMSC47M1_FAN2_DIV 76 /* RW */
+#define SENSORS_SMSC47M1_FAN3_DIV 77 /* RW */
 #define SENSORS_SMSC47M1_ALARMS 81 /* R */
 
 #define SENSORS_SMSC47M192_PREFIX "smsc47m192"
@@ -1933,6 +1974,14 @@
 #define SENSORS_PC87360_VID		240	/* R */
 #define SENSORS_PC87360_VRM		241	/* RW */
 
+#define SENSORS_PC87427_PREFIX "pc87427"
+
+/* fan n from 1 to 8 */
+#define SENSORS_PC87427_FAN(n)		(n)		/* R */
+#define SENSORS_PC87427_FAN_MIN(n)	(16 + (n))	/* RW */
+#define SENSORS_PC87427_FAN_ALARM(n)	(32 + (n))	/* R */
+#define SENSORS_PC87427_FAN_FAULT(n)	(48 + (n))	/* R */
+
 #define SENSORS_LM92_PREFIX "lm92"
 
 #define SENSORS_LM92_TEMP_HIGH		1	/* RW */
@@ -2170,10 +2219,11 @@
 #define SENSORS_SMSC47B397_FAN3		0x13 /* R */
 #define SENSORS_SMSC47B397_FAN4		0x14 /* R */
 
-/* Fintek F71805F chip */
+/* Fintek F71805F/FG and F71872F/FG chips */
 #define SENSORS_F71805F_PREFIX		"f71805f"
+#define SENSORS_F71872F_PREFIX		"f71872f"
 
-/* in n from 0 to 8 */
+/* in n from 0 to 10 */
 #define SENSORS_F71805F_IN(n)		(1 + (n))
 #define SENSORS_F71805F_IN_MIN(n)	(16 + (n))
 #define SENSORS_F71805F_IN_MAX(n)	(31 + (n))
@@ -2190,8 +2240,9 @@
 #define SENSORS_F71805F_ALARMS_FAN	201
 #define SENSORS_F71805F_ALARMS_TEMP	202
 
-/* Abit uGuru chip */
+/* Abit uGuru chips */
 #define SENSORS_ABITUGURU_PREFIX "abituguru"
+#define SENSORS_ABITUGURU3_PREFIX "abituguru3"
 
 /* in n from 0 to 10 */
 #define SENSORS_ABITUGURU_IN(n)			(0x01 + (n)) /* R */
@@ -2216,4 +2267,74 @@
 #define SENSORS_K8TEMP_TEMP3	0x03 /* R */
 #define SENSORS_K8TEMP_TEMP4	0x04 /* R */
 
+/* coretemp */
+
+#define SENSORS_CORETEMP_PREFIX "coretemp"
+#define SENSORS_CORETEMP_TEMP1			0x01 /* R */
+#define SENSORS_CORETEMP_TEMP1_CRIT		0x02 /* R */
+#define SENSORS_CORETEMP_TEMP1_CRIT_ALARM	0x03 /* R */
+
+/* DME1737 */
+
+#define SENSORS_DME1737_PREFIX "dme1737"
+
+/* in n from 0 to 6 */
+#define SENSORS_DME1737_IN(n)			(0x01 + (n)) /* R */
+#define SENSORS_DME1737_IN_MIN(n)		(0x11 + (n)) /* RW */
+#define SENSORS_DME1737_IN_MAX(n)		(0x21 + (n)) /* RW */
+#define SENSORS_DME1737_IN_ALARM(n)		(0x31 + (n)) /* R */
+
+/* temp n from 1 to 3*/
+#define SENSORS_DME1737_TEMP(n)			(0x41 + (n)) /* R */
+#define SENSORS_DME1737_TEMP_MIN(n)		(0x51 + (n)) /* RW */
+#define SENSORS_DME1737_TEMP_MAX(n)		(0x61 + (n)) /* RW */
+#define SENSORS_DME1737_TEMP_ALARM(n)		(0x71 + (n)) /* R */
+#define SENSORS_DME1737_TEMP_FAULT(n)		(0x81 + (n)) /* R */
+
+/* fan n from 1 to 6 */
+#define SENSORS_DME1737_FAN(n)			(0x91 + (n)) /* R */
+#define SENSORS_DME1737_FAN_MIN(n)		(0xa1 + (n)) /* RW */
+#define SENSORS_DME1737_FAN_ALARM(n)		(0xb1 + (n)) /* R */
+
+/* pwm n from 1 to 3 and 5 to 6 */
+#define SENSORS_DME1737_PWM(n)			(0xc1 + (n)) /* RW */
+#define SENSORS_DME1737_PWM_ENABLE(n)		(0xd1 + (n)) /* RW */
+#define SENSORS_DME1737_PWM_FREQ(n)		(0xe1 + (n)) /* RW */
+
+#define SENSORS_DME1737_VID			(0xf0) /* R */
+#define SENSORS_DME1737_VRM			(0xf1) /* RW */
+
+/* applesmc */
+
+#define SENSORS_APPLESMC_PREFIX "applesmc"
+
+/* temp n from 0 to 11 */
+#define SENSORS_APPLESMC_TEMP(n)		(0x01 + (n)) /* R */
+
+/* fan n from 0 to 1 */
+#define SENSORS_APPLESMC_FAN(n)			(0x21 + (n)) /* R */
+#define SENSORS_APPLESMC_FAN_MIN(n)		(0x41 + (n)) /* R */
+#define SENSORS_APPLESMC_FAN_MAX(n)		(0x61 + (n)) /* R */
+#define SENSORS_APPLESMC_FAN_SAFE(n)		(0x81 + (n)) /* R */
+
+/* Fintek F71882FG and F71883FG chips */
+#define SENSORS_F71882FG_PREFIX		"f71882fg"
+
+/* in n from 0 to 8 */
+#define SENSORS_F71882FG_IN(n)			(1 + (n))
+#define SENSORS_F71882FG_IN_MAX(n)		(16 + (n))
+#define SENSORS_F71882FG_IN_ALARM(n)		(31 + (n))
+/* fan n from 1 to 4 */
+#define SENSORS_F71882FG_FAN(n)			(50 + (n))
+#define SENSORS_F71882FG_FAN_ALARM(n)		(60 + (n))
+/* temp n from 1 to 3 */
+#define SENSORS_F71882FG_TEMP(n)		(80 + (n))
+#define SENSORS_F71882FG_TEMP_MAX(n)		(90 + (n))
+#define SENSORS_F71882FG_TEMP_MAX_HYST(n)	(100 + (n))
+#define SENSORS_F71882FG_TEMP_CRIT(n)		(110 + (n))
+#define SENSORS_F71882FG_TEMP_CRIT_HYST(n)	(120 + (n))
+#define SENSORS_F71882FG_TEMP_ALARM(n)		(130 + (n))
+#define SENSORS_F71882FG_TEMP_FAULT(n)		(140 + (n))
+#define SENSORS_F71882FG_TEMP_TYPE(n)		(150 + (n))
+
 #endif /* def LIB_SENSORS_CHIPS_H */
