@@ -25,6 +25,8 @@
 #include "error.h"
 #include "access.h"
 #include "conf.h"
+#include "sysfs.h"
+#include "scanner.h"
 
 static void free_proc_chips_entry(sensors_proc_chips_entry entry);
 static void free_chip_name(sensors_chip_name name);
@@ -40,14 +42,18 @@ int sensors_init(FILE *input)
 {
   int res;
   sensors_cleanup();
-  if ((res = sensors_read_proc_chips()))
-    return res;
-  if ((res = sensors_read_proc_bus()))
-    return res;
-  sensors_yyin = input;
+  if (sensors_init_sysfs()) {
+    if ((res = sensors_read_sysfs_bus()) || (res = sensors_read_sysfs_chips()))
+      return res;
+  } else {
+    if ((res = sensors_read_proc_bus()) || (res = sensors_read_proc_chips()))
+      return res;
+  }
+  if ((res = sensors_scanner_init(input)))
+    return -SENSORS_ERR_PARSE;
   if ((res = sensors_yyparse()))
     return -SENSORS_ERR_PARSE;
-  if ((res = sensors_substitute_busses()));
+  if ((res = sensors_substitute_busses()))
     return res;
   return 0;
 }
@@ -56,6 +62,8 @@ void sensors_cleanup(void)
 {
   int i;
 
+  sensors_scanner_exit();
+
   for (i = 0; i < sensors_proc_chips_count; i++)
     free_proc_chips_entry(sensors_proc_chips[i]);
   free(sensors_proc_chips);
@@ -95,13 +103,17 @@ void free_chip_name(sensors_chip_name name)
 void free_bus(sensors_bus bus)
 {
   free(bus.adapter);
-  free(bus.algorithm);
 }
 
 void free_chip(sensors_chip chip)
 {
   int i;
 
+  for (i = 0; i < chip.chips.fits_count; i++)
+    free_chip_name(chip.chips.fits[i]);
+  free(chip.chips.fits);
+  chip.chips.fits_count = chip.chips.fits_max = 0;
+
   for (i = 0; i < chip.labels_count; i++)
     free_label(chip.labels[i]);
   free(chip.labels);
