@@ -2,7 +2,7 @@
 
 #    mkpatch - Create patches against the Linux kernel
 #    Copyright (C) 1999  Frodo Looijaard <frodol@dds.nl>
-#    Copyright (C) 2005  Jean Delvare <khali@linux-fr.org>
+#    Copyright (C) 2005-2007  Jean Delvare <khali@linux-fr.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -135,6 +135,7 @@ sub gen_Documentation_Configure_help
            m@Winbond W83781D, W83782D, W83783S@ or
            m@Winbond W83792D@ or
            m@Winbond W83627HF, W83627THF@ or
+           m@Winbond W83627EHF/EHG@ or
            m@Winbond W83L785TS-S@ or
            m@EEprom \(DIMM\) reader@) {
       $_ = <INPUT>;
@@ -224,9 +225,11 @@ Intel 82371AB PIIX4(E), ServerWorks OSB4, CSB5, CSB6, HT-1000
 CONFIG_I2C_PIIX4
   If you say yes to this option, support will be included for the
   Intel PIIX4, PIIX4E, 443MX, Serverworks OSB4, CSB5, CSB6 and
-  HT-1000, ATI IXP200, IXP300 and IXP400, and SMSC Victory66 mainboard
-  I2C interfaces. This can also be built as a module which can be
-  inserted and removed while the kernel is running.
+  HT-1000, ATI IXP200, IXP300, IXP400 and SB600, and SMSC Victory66
+  mainboard SMBus interfaces.
+  
+  This can also be built as a module which can be inserted and removed
+  while the kernel is running.
 
 Nvidia Nforce2/3/4 based Mainboard
 CONFIG_I2C_NFORCE2
@@ -264,7 +267,7 @@ CONFIG_I2C_VIA
   be built as a module which can be inserted and removed while the
   kernel is running.
 
-VIA Technologies, Inc. VT82C596, 596B, 686A/B, 8233, 8235, 8237R/A, 8251
+VIA Technologies, Inc. VT82C596/82C686/82xx and CX700
 CONFIG_I2C_VIAPRO
   If you say yes to this option, support will be included for the VIA
   Technologies I2C adapter on these chips. For integrated sensors on the
@@ -728,6 +731,16 @@ CONFIG_SENSORS_W83627HF
   them in the lm_sensors package, which you can download at
   http://www.lm-sensors.org/
 
+Winbond W83627EHF/EHG
+CONFIG_SENSORS_W83627EHF
+  If you say yes here you get support for the Winbond W83627EHF/EHG
+  sensor chips. This can also be built as a module which can be
+  inserted and removed while the kernel is running.
+
+  You will also need the latest user-space utilities: you can find
+  them in the lm_sensors package, which you can download at
+  http://www.lm-sensors.org/
+
 Winbond W83L785TS-S
 CONFIG_SENSORS_W83L785TS
   If you say yes here you get support for the Winbond W83L785TS-S
@@ -985,7 +998,7 @@ sub gen_drivers_i2c_Config_in
     dep_tristate '  SiS 645/961,645DX/961,735' CONFIG_I2C_SIS645 $CONFIG_I2C $CONFIG_HOTPLUG
     dep_tristate '  Savage 4' CONFIG_I2C_SAVAGE4 $CONFIG_I2C_ALGOBIT
     dep_tristate '  VIA Technologies, Inc. VT82C586B' CONFIG_I2C_VIA $CONFIG_I2C_ALGOBIT
-    dep_tristate '  VIA Technologies, Inc. VT596A/B, 686A/B, 8231, 8233, 8233A, 8235, 8237R/A, 8251' CONFIG_I2C_VIAPRO $CONFIG_I2C
+    dep_tristate '  VIA Technologies, Inc. VT82C596/82C686/82xx and CX700' CONFIG_I2C_VIAPRO $CONFIG_I2C
     dep_tristate '  Voodoo3 I2C interface' CONFIG_I2C_VOODOO3 $CONFIG_I2C_ALGOBIT
     dep_tristate '  Pseudo ISA adapter (for some hardware sensors)' CONFIG_I2C_ISA $CONFIG_I2C
   fi
@@ -1061,6 +1074,7 @@ obj-$(CONFIG_SENSORS_VT8231)	+= vt8231.o
 obj-$(CONFIG_SENSORS_W83781D)	+= w83781d.o
 obj-$(CONFIG_SENSORS_W83792D)	+= w83792d.o
 obj-$(CONFIG_SENSORS_W83627HF)	+= w83627hf.o
+obj-$(CONFIG_SENSORS_W83627EHF)	+= w83627ehf.o
 obj-$(CONFIG_SENSORS_W83L785TS)	+= w83l785ts.o
 obj-$(CONFIG_SENSORS_XEONTEMP)	+= xeontemp.o
 
