@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include "i2cbusses.h"
+#include "util.h"
 #include "i2c-dev.h"
 #include "version.h"
 
@@ -32,7 +33,7 @@ void help(void) __attribute__ ((noreturn));
 
 void help(void)
 {
-	fprintf(stderr, "Syntax: i2cset [-y] I2CBUS CHIP-ADDRESS DATA-ADDRESS "
+	fprintf(stderr, "Syntax: i2cset [-f] [-y] I2CBUS CHIP-ADDRESS DATA-ADDRESS "
 	        "VALUE [MODE] [MASK]\n"
 	        "        i2cset -V\n"
 	        "  MODE is 'b[yte]' or 'w[ord]' (default b)\n"
@@ -49,15 +50,16 @@ int main(int argc, char *argv[])
 	int value, daddress, vmask = 0;
 	int e1;
 	char filename[20];
-	long funcs;
+	unsigned long funcs;
 	int pec = 0;
 	int flags = 0;
-	int yes = 0, version = 0;
+	int force = 0, yes = 0, version = 0;
 
 	/* handle (optional) flags first */
 	while (1+flags < argc && argv[1+flags][0] == '-') {
 		switch (argv[1+flags][1]) {
 		case 'V': version = 1; break;
+		case 'f': force = 1; break;
 		case 'y': yes = 1; break;
 		default:
 			fprintf(stderr, "Warning: Unsupported flag "
@@ -159,16 +161,10 @@ int main(int argc, char *argv[])
 		break;
 	}
 
-	/* use FORCE so that we can write registers even when
-	   a driver is also running */
-	if (ioctl(file, I2C_SLAVE_FORCE, address) < 0) {
-		fprintf(stderr, "Error: Could not set address to %d: %s\n",
-		        address, strerror(errno));
+	if (set_slave_addr(file, address, force) < 0)
 		exit(1);
-	}
 
 	if (!yes) {
-		char s[2];
 		int dont = 0;
 
 		fprintf(stderr, "WARNING! This program can confuse your I2C "
@@ -192,8 +188,7 @@ int main(int argc, char *argv[])
 
 		fprintf(stderr, "Continue? [%s] ", dont ? "y/N" : "Y/n");
 		fflush(stderr);
-		if (!fgets(s, 2, stdin)
-		 || ((s[0] != '\n' || dont) && s[0] != 'y' && s[0] != 'Y')) {
+		if (!user_ack(!dont)) {
 			fprintf(stderr, "Aborting on user request.\n");
 			exit(0);
 		}
@@ -216,8 +211,6 @@ int main(int argc, char *argv[])
 		value = (value & vmask) | (oldvalue & ~vmask);
 
 		if (!yes) {
-			char s[2];
-			
 			fprintf(stderr, "Old value 0x%0*x, write mask "
 				"0x%0*x: Will write 0x%0*x to register "
 				"0x%02x\n",
@@ -228,8 +221,7 @@ int main(int argc, char *argv[])
 
 			fprintf(stderr, "Continue? [Y/n] ");
 			fflush(stderr);
-			if (!fgets(s, 2, stdin)
-			 || (s[0] != '\n' && s[0] != 'y' && s[0] != 'Y')) {
+			if (!user_ack(1)) {
 				fprintf(stderr, "Aborting on user request.\n");
 				exit(0);
 			}
