@@ -54,7 +54,7 @@ static const char *sprintf_chip_name(sensors_chip_name name);
 #define CHIPS_MAX 20
 sensors_chip_name chips[CHIPS_MAX];
 int chips_count=0;
-int do_sets, do_unknown, fahrenheit, show_algorithm, hide_adapter, hide_unknown;
+int do_sets, do_unknown, fahrenheit, hide_adapter, hide_unknown;
 
 char degstr[5]; /* store the correct string to print degrees */
 
@@ -70,7 +70,6 @@ void print_long_help(void)
   printf("  -h, --help            Display this help text\n");
   printf("  -s, --set             Execute `set' statements too (root only)\n");
   printf("  -f, --fahrenheit      Show temperatures in degrees fahrenheit\n");
-  printf("  -a, --algorithm       Show algorithm for each chip\n");
   printf("  -A, --no-adapter      Do not show adapter for each chip\n");
   printf("  -U, --no-unknown      Do not show unknown chips\n");
   printf("  -u, --unknown         Treat chips as unknown ones (testing only)\n");
@@ -95,7 +94,7 @@ void print_version(void)
 
 /* This examines global var config_file, and leaves the name there too. 
    It also opens config_file. */
-void open_config_file(const char* config_file_name)
+static void open_config_file(const char* config_file_name)
 {
   if (!strcmp(config_file_name,"-")) {
     config_file = stdin;
@@ -110,7 +109,7 @@ void open_config_file(const char* config_file_name)
   }
 }
     
-void close_config_file(const char* config_file_name)
+static void close_config_file(const char* config_file_name)
 {
   if (fclose(config_file) == EOF) {
     fprintf(stderr,"Could not close config file\n");
@@ -149,18 +148,19 @@ static void set_degstr(void)
 int main (int argc, char *argv[])
 {
   int c,res,i,error;
-  char *config_file_name = NULL;
+  const char *config_file_name = ETCDIR "/" DEFAULT_CONFIG_FILE_NAME;
 
   struct option long_opts[] =  {
     { "help", no_argument, NULL, 'h' },
     { "set", no_argument, NULL, 's' },
     { "version", no_argument, NULL, 'v'},
     { "fahrenheit", no_argument, NULL, 'f' },
-    { "algorithm", no_argument, NULL, 'a' },
     { "no-adapter", no_argument, NULL, 'A' },
     { "no-unknown", no_argument, NULL, 'U' },
     { "config-file", required_argument, NULL, 'c' },
     { "unknown", no_argument, NULL, 'u' },
+    /* next option accepted for compatibility, but otherwise ignored */
+    { "algorithm", no_argument, NULL, 'a' },
     { 0,0,0,0 }
   };
 
@@ -168,7 +168,6 @@ int main (int argc, char *argv[])
 
   do_unknown = 0;
   do_sets = 0;
-  show_algorithm = 0;
   hide_adapter = 0;
   hide_unknown = 0;
   while (1) {
@@ -187,7 +186,7 @@ int main (int argc, char *argv[])
       print_version();
       exit(0);
     case 'c':
-      config_file_name = strdup(optarg);
+      config_file_name = optarg;
       break;
     case 's':
       do_sets = 1;
@@ -195,9 +194,6 @@ int main (int argc, char *argv[])
     case 'f':
       fahrenheit = 1;
       break;
-    case 'a':
-      show_algorithm = 1;
-      break;
     case 'A':
       hide_adapter = 1;
       break;
@@ -207,6 +203,9 @@ int main (int argc, char *argv[])
     case 'u':
       do_unknown = 1;
       break;
+    case 'a':
+      /* Ignore for compatibility */
+      break;
     default:
       fprintf(stderr,"Internal error while parsing options!\n");
       exit(1);
@@ -229,11 +228,7 @@ int main (int argc, char *argv[])
         exit(1);
       }
 
-
-  if (config_file_name == NULL)
-    config_file_name = strdup(ETCDIR "/" DEFAULT_CONFIG_FILE_NAME);
   open_config_file(config_file_name);
-
   if ((res = sensors_init(config_file))) {
     fprintf(stderr,"%s\n",sensors_strerror(res));
     if (res == -SENSORS_ERR_PROC)
@@ -243,9 +238,7 @@ int main (int argc, char *argv[])
               "was compiled with sysfs support!\n");
     exit(1);
   }
-
   close_config_file(config_file_name);
-  free(config_file_name);
 
   /* build the degrees string */
   set_degstr();
@@ -331,7 +324,7 @@ struct match {
 	void (*fn) (const sensors_chip_name *name);
 };
 
-struct match matches[] = {
+static struct match matches[] = {
 	{ "ds1621", print_ds1621 },
 	{ "lm75", print_lm75 },
 	{ "adm1021", print_adm1021 },
@@ -374,6 +367,7 @@ struct match matches[] = {
 	{ "w83697hf", print_w83781d },
 	{ "w83687thf", print_w83781d },
 	{ "w83627ehf", print_w83627ehf },
+	{ "w83627dhg", print_w83627ehf },
 	{ "w83791d", print_w83781d },
 	{ "w83792d", print_w83792d },
 	{ "w83793", print_w83793 },
@@ -388,8 +382,6 @@ struct match matches[] = {
 	{ "it8712", print_it87 },
 	{ "it8716", print_it87 },
 	{ "it8718", print_it87 },
-	{ "ddcmon", print_ddcmon },
-	{ "eeprom", print_eeprom },
 	{ "fscpos", print_fscpos },
 	{ "fscscy", print_fscscy },
 	{ "fscher", print_fscher },
@@ -397,11 +389,13 @@ struct match matches[] = {
 	{ "vt1211", print_vt1211 },
 	{ "smsc47m192", print_smsc47m192 },
 	{ "smsc47m1", print_smsc47m1 },
+	{ "smsc47m2", print_smsc47m1 },
 	{ "pc87360", print_pc87360 },
 	{ "pc87363", print_pc87360 },
 	{ "pc87364", print_pc87364 },
 	{ "pc87365", print_pc87366 },
 	{ "pc87366", print_pc87366 },
+	{ "pc87427", print_pc87427 },
 	{ "lm92", print_lm92 },
 	{ "vt8231", print_vt8231 },
 	{ "bmc", print_bmc },
@@ -413,23 +407,30 @@ struct match matches[] = {
 	{ "lm86", print_lm90 },
 	{ "max6657", print_lm90 },
 	{ "adt7461", print_lm90 },
+	{ "max6680", print_lm90 },
 	{ "lm63", print_lm63 },
 	{ "xeontemp", print_xeontemp },
 	{ "max6650", print_max6650 },
 	{ "asb100", print_asb100 },
+	{ "adm1029", print_adm1029 },
 	{ "adm1030", print_adm1031 },
 	{ "adm1031", print_adm1031 },
 	{ "lm93", print_lm93 },
 	{ "smsc47b397", print_smsc47b397 },
 	{ "f71805f", print_f71805f },
+	{ "f71872f", print_f71805f },
  	{ "abituguru", print_abituguru },
+ 	{ "abituguru3", print_abituguru3 },
  	{ "k8temp", print_k8temp },
+ 	{ "coretemp", print_coretemp },
+ 	{ "dme1737", print_dme1737 },
+	{ "applesmc", print_applesmc },
+	{ "f71882fg", print_f71882fg },
 	{ NULL, NULL }
 };
 
 void do_a_print(sensors_chip_name name)
 {
-  const char *algo,*adap;
   struct match *m;
 
   /* do we know how to display it? */
@@ -440,15 +441,19 @@ void do_a_print(sensors_chip_name name)
   if(m->prefix==NULL && hide_unknown)
     return;
 
+  /* Explicitly reject eeprom and ddcmon, we no longer support them
+     but libsensors may */
+  if (!strcmp(name.prefix, "eeprom") || !strcmp(name.prefix, "ddcmon"))
+    return;
+
   printf("%s\n",sprintf_chip_name(name));
-  adap = sensors_get_adapter_name(name.bus);
-  if (adap && !hide_adapter)
-    printf("Adapter: %s\n",adap);
-  algo = sensors_get_algorithm_name(name.bus);
-  if (algo && show_algorithm)
-    printf("Algorithm: %s\n",algo);
-  if (!algo || !adap)
-    printf(" ERROR: Can't get adapter or algorithm?!?\n");
+  if (!hide_adapter) {
+    const char *adap = sensors_get_adapter_name(name.bus);
+    if (adap)
+      printf("Adapter: %s\n", adap);
+    else
+      fprintf(stderr, "Can't get adapter name for bus %d\n", name.bus);
+  }
   if (do_unknown)
     print_unknown_chip(&name);
   else {
